package com.sinosig.core.module.service;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;
import java.math.BigInteger;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import com.sinosig.core.module.domain.CID;
import com.sinosig.core.module.filter.CIDSearchContext;

/**
 * 实体[CID] 服务对象接口
 */

public interface ICIDService{
     boolean checkKey(CID cid) ;
     CID createTemp(CID cid) ;
     CID removeTemp(CID cid) ;
     CID getMRSYXXX(CID cid) ;
     boolean create(CID cid) ;
     CID getOrgNameByUser(CID cid) ;
     CID removeTempMajor(CID cid) ;
     CID getTempMajor(CID cid) ;
     CID get(String cidid) ;
     CID get(CID cid) ;
     CID getDraftTemp(CID cid) ;
     CID updateTempMajor(CID cid) ;
     CID updateTemp(CID cid) ;
     CID getDraft(CID cid) ;
     CID jSBF(CID cid) ;
     CID getMRJQXXX(CID cid) ;
     boolean update(CID cid) ;
     CID getTemp(CID cid) ;
     boolean save(CID cid) ;
     CID getDraftTempMajor(CID cid) ;
     boolean remove(String cidid) ;
     CID getCPXHXX(CID cid) ;
     CID createTempMajor(CID cid) ;

    /**
     * 查询集合 DEFAULT
     */
     Page<CID> searchDefault(CIDSearchContext context) ;

    /**
     * 根据厂牌型号查询
     */
     Page<CID> selectByCPXH(String cpxhid) ;
     List<CID> selectByCPXH2(String cpxhid);

    /**
     * 根据人员查询
     */
     Page<CID> selectByORGUSER(String orguserid) ;
     List<CID> selectByORGUSER2(String orguserid);

    /**
     * 根据机构查询
     */
     Page<CID> selectByORG(String orgid) ;
     List<CID> selectByORG2(String orgid);

}
